
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.117'
version = '1.2.117'
full_version = '1.2.117'
git_revision = 'b0a40d1f6f1852c56c27b3df4cec97d36ac0463f'
release = True

if not release:
    version = full_version
    short_version += ".dev"
